@@ -1,11 +1,10 @@
 from pathlib import Path
 
-from lawsql_utils.files import load_yaml_list
-
 from .unformatted import (
     fix_absent_signer_problem,
     fix_multiple_sections_in_first,
 )
+from .utils import load_yaml_list
 
 
 def set_units(folder: Path, data: dict):
