@@ -2,7 +2,7 @@ import codecs
 from pathlib import Path
 from typing import Optional
 
-from lawsql_utils.files import load_yaml_from_path
+from .utils import load_yaml_from_path
 
 
 def set_whereas(loc: Path) -> dict:
